<TS language="uz@Cyrl" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Янги манзил яратинг</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Янги</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Жорий танланган манзилни тизим вақтинчалик хотирасига нусха кўчиринг</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Нусха олиш</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Ёпиш</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Жорий танланган манзилни рўйхатдан ўчириш</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Излаш учун манзил ёки ёрлиқни киритинг</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Жорий ички ойна ичидаги маълумотларни файлга экспорт қилиш</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Экспорт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Ўчириш</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Тангаларни жўнатиш учун манзилни танланг</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Тангаларни қабул қилиш учун манзилни танланг</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Танлаш</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Жўнатиладиган манзиллар</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Қабул қилинадиган манзиллар</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Улар тўловларни жўнатиш учун сизнинг Bitcoin манзилларингиз. Доимо тангаларни жўнатишдан олдин сумма ва қабул қилувчи манзилни текшириб кўринг. </translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Манзилдан &amp;нусха олиш</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Нусха олиш ва ёрлиқ</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Таҳрирлаш</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Манзил рўйхатини экспорт қилиш</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Вергул билан ажратилган файл (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Экспорт қилиб бўлмади</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Манзил рўйхатини %1.га сақлашда хатолик юз берди. Яна уриниб кўринг.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Ёрлиқ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Манзил</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Ёрлиқ мавжуд эмас)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Махфий сўз ойнаси</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Махфий сузни киритинг</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Янги махфий суз</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Янги махфий сузни такрорланг</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Ҳамённи қодлаш</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ушбу операцияни амалга ошириш учун ҳамённи қулфдан чиқариш парол сўзини талаб қилади.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Ҳамённи қулфдан чиқариш</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Ушбу операцияни амалга ошириш учун ҳамённи коддан чиқариш парол сўзини талаб қилади.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Ҳамённи коддан чиқариш</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Махфий сузни узгартириш</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Ҳамённи кодлашни тасдиқлаш</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Диққат: Агар сиз ҳамёнингизни кодласангиз ва махфий сўзингизни унутсангиз, сиз &lt;b&gt;БАРЧА BITCOIN ПУЛЛАРИНГИЗНИ ЙЎҚОТАСИЗ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Ҳамёнингизни кодлашни ростдан хоҳлайсизми?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Ҳамёни кодланган</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Ҳамёнга янги махфий сўз киритинг.&lt;br/&gt;Илтимос, &lt;b&gt;ўнта ёки тасодифий белгили&lt;/b&gt; махфий сўздан фойдаланинг ёки &lt;b&gt;саккизта ёки кўпроқ сўзлар&lt;/b&gt;дан фойдаланинг.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>МУҲИМ: Сиз қилган олдинги ҳамён файли заҳиралари янги яратилган, кодланган ҳамён файли билан алмаштирилиши керак. Хавфсизлик сабабларига кўра олдинги кодланган ҳамён файли заҳираси янги кодланган ҳамёндан фойдаланишингиз билан яроқсиз ҳолга келади.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Ҳамённи кодлаш амалга ошмади</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Ҳамённи кодлаш ташқи хато туфайли амалга ошмади. Ҳамёнингиз кодланмади.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Киритилган пароллар мос келмади.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Ҳамённи қулфдан чиқариш амалга ошмади</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Ҳамённи коддан чиқариш учун киритилган парол нотўғри.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Ҳамённи коддан чиқариш амалга ошмади</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Ҳамён пароли муваффақиятли алмаштирилди.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Диққат: Caps Lock тугмаси ёқилган!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;Хабар ёзиш...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Тармоқ билан синхронланмоқда...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Кўриб чиқиш</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Ҳамённинг умумий кўринишини кўрсатиш</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Пул ўтказмалари</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Пул ўтказмалари тарихини кўриш</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Ч&amp;иқиш</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Иловадан чиқиш</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>%1 ҳақидаги маълумотларни кўрсатиш</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt ҳақида</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Qt ҳақидаги маълумотларни кўрсатиш</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Мосламалар...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Ҳамённи &amp;кодлаш...</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Ҳамённи &amp;заҳиралаш...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Махфий сўзни &amp;ўзгартириш...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Интернет манзилни очиш</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Ҳамён:</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Дискдаги блоклар қайта индексланмоқда...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Тангаларни Bitcoin манзилига жўнатиш</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Ҳамённи бошқа манзилга заҳиралаш</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Паролни ўзгартириш ҳамённи кодлашда фойдаланилади</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>Хабарни &amp;тасдиқлаш...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Жўнатиш</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Қабул қилиш</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Кўрсатиш / Яшириш</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Асосий ойнани кўрсатиш ёки яшириш</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Ҳамёнингизга тегишли махфий калитларни кодлаш</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>Bitcoin манзилидан унинг эгаси эканлигингизни исботлаш учун хабарлар ёзинг</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Хабарларни махсус Bitcoin манзилларингиз билан ёзилганлигига ишонч ҳосил қилиш учун уларни тасдиқланг</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp; Созламалар</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ёрдам</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Ички ойналар асбоблар панели</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Тўловлар (QR кодлари ва bitcoin ёрдамида яратишлар: URI’лар) сўраш</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Фойдаланилган жўнатилган манзиллар ва ёрлиқлар рўйхатини кўрсатиш</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Фойдаланилган қабул қилинган манзиллар ва ёрлиқлар рўйхатини кўрсатиш</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Буйруқлар сатри мосламалари</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Дискдаги блоклар қайта индексланмоқда...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 орқада</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Сўнги қабул қилинган блок %1 олдин яратилган.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Бундан кейинги пул ўтказмалари кўринмайдиган бўлади.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Хатолик</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Диққат</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Маълумот</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Янгиланган</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>Носозликни ҳал қилиш ва ташхис терминали</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Жўнатилувчи манзиллар</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Қабул қилувчи манзиллар</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation>Мавжуд Bitcoin буйруқлар матни мосламалари билан  %1 ёрдам хабарларини олиш рўйхатини кўрсатиш</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ойна</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Камайтириш</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished"><numerusform>%n та Bitcoin тармоғига фаол уланиш мавжуд</numerusform><numerusform>%n та Bitcoin тармоғига фаол уланиш мавжуд</numerusform></translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Банд қилинмоқда...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Жўнатилган операция</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Кирувчи операция</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Ҳамён &lt;b&gt;кодланган&lt;/b&gt; ва вақтинча &lt;b&gt;қулфдан чиқарилган&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Ҳамён &lt;b&gt;кодланган&lt;/b&gt; ва вақтинча &lt;b&gt;қулфланган&lt;/b&gt;</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation>Жиддий хато юз берди. %1 хавфсиз ишлай олмайди, шунинг учун чиқиб кетилади.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Сони:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байт:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Миқдори:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Солиқ:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Ахлат қутиси:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Солиқдан сўнг:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Ўзгартириш:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>барчасини танаш (бекор қилиш)</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Дарахт усулида</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Рўйхат усулида</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Миқдори</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Сана</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Тасдиқлашлар</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Тасдиқланди</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Кийматни нусхала</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Манзилни нусхалаш</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Ёрликни нусхала</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Кийматни нусхала</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Ўтказам рақамидан нусха олиш</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">&amp;Сарфланмаганларни қулфлаш</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Сарфланмаганларни қулфдан чиқариш</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Нусха сони</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Нусха солиғи</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Нусха солиқдан сўнг</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Нусха байти</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Нусха чангги</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Нусха қайтими</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 қулфланган)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ҳа</translation>
    </message>
    <message>
        <source>no</source>
        <translation>йўқ</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation>Ҳар бир кирим +/- %1 сатоши(лар) билан ўзгариши мумкин.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Ёрлиқ мавжуд эмас)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>%1 (%2)дан ўзгартириш</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(ўзгартириш)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Ҳамён</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Ҳамённи кодлаш</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Манзилларни таҳрирлаш</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Ёрлик</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Ёрлиқ ушбу манзилар рўйхати ёзуви билан боғланган</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Манзил ушбу манзиллар рўйхати ёзуви билан боғланган. Уни фақат жўнатиладиган манзиллар учун ўзгартирса бўлади.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Манзил</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Янги жунатилувчи манзил</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Кабул килувчи манзилни тахрирлаш</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Жунатилувчи манзилни тахрирлаш</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation>Киритилган "%1" манзили тўғри Bitcoin манзили эмас.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ҳамён қулфдан чиқмади.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Янги калит яратиш амалга ошмади.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>Янги маълумотлар директорияси яратилади.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>номи</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Директория аллақачон мавжуд. Агар бу ерда янги директория яратмоқчи бўлсангиз, %1 қўшинг.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Йўл аллақачон мавжуд. У директория эмас.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Маълумотлар директориясини бу ерда яратиб бўлмайди..</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>версияси</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Буйруқлар сатри мосламалари</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Хуш келибсиз</translation>
    </message>
    <message>
        <source>As this is the first time the program is launched, you can choose where %1 will store its data.</source>
        <translation>Биринчи марта дастур ишга тушгани каби сиз %1 маълумотларини жойлаштирадиган жойни танлашингиз мумкин.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Стандарт маълумотлар директориясидан фойдаланиш</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Бошқа маълумотлар директориясида фойдаланинг:</translation>
    </message>
    <message>
        <source>At least %1 GB of data will be stored in this directory, and it will grow over time.</source>
        <translation>Камида %1GB  маълумот ушбу директорияга жойлаштирилади ва вақт давомида ўсиб боради.</translation>
    </message>
    <message>
        <source>%1 will download and store a copy of the Bitcoin block chain.</source>
        <translation>%1 юклаб олинади ва Bitcoin блок занжири нусхаси жойлаштирилади.</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Ҳамён ҳам ушбу директорияда жойлашади.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation>Хато: кўрсатилган "%1" маълумотлар директориясини яратиб бўлмайди.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Хатолик</translation>
    </message>
    </context>
<context>
    <name>MempoolStats</name>
    <message>
        <source>N/A</source>
        <translation>Тўғри келмайди</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Шакл</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation type="unfinished">Номаълум...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Сўнгги блок вақти</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Type</source>
        <comment>NetWatch: Type header</comment>
        <translation>Тури</translation>
    </message>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Манзил</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Клипбоарддан манзилни қўйиш</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Танламалар</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Асосий</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>&amp;Маълумотлар базаси кеши</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Мавзуларни &amp;тўғрилаш скрипти миқдори</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation>Прокси IP манзили (масалан: IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>Тармоқ</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Ҳамён</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation type="unfinished">Ташқаридан уланишларга рози бўлиш.</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation type="unfinished">&amp;Кирувчи уланишларга рухсат бериш</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation>Прокси &amp;IP рақами:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Порт:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Прокси порти (e.g. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ойна</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Ойна йиғилгандан сўнг фақат трэй нишончаси кўрсатилсин.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>Манзиллар панели ўрнига трэйни &amp;йиғиш</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>Ёпишда й&amp;иғиш</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Кўрсатиш</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Фойдаланувчи интерфейси &amp;тили:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Миқдорларни кўрсатиш учун &amp;қисм:</translation>
    </message>
    <message>
        <source>&amp;Third party transaction URLs</source>
        <translation type="unfinished">&amp;Бегона тараф ўтказмалари URL манзиллари</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Бекор қилиш</translation>
    </message>
    <message>
        <source>default</source>
        <translation>стандарт</translation>
    </message>
    <message>
        <source>none</source>
        <translation>йўқ</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Тасдиқлаш танловларини рад қилиш</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Ўзгаришлар амалга ошиши учун мижозни қайта ишга тушириш талаб қилинади.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Хатолик</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Ушбу ўзгариш мижозни қайтадан ишга туширишни талаб қилади.</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Келтирилган прокси манзили ишламайди.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Шакл</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation>Кўрсатилган маълумот эскирган бўлиши мумкин. Ҳамёнингиз алоқа ўрнатилгандан сўнг Bitcoin тармоқ билан автоматик тарзда синхронланади, аммо жараён ҳалигача тугалланмади.</translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation>Фақат кўришга</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Мавжуд:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Жорий сарфланадиган балансингиз</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>Кутилмоқда:</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation>Жами ўтказмалар ҳозиргача тасдиқланган ва сафланадиган баланс томонга ҳали ҳам ҳисобланмади</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Тайёр эмас:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation>Миналаштирилган баланс ҳалигача тайёр эмас</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Баланслар</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Жами:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Жорий умумий балансингиз</translation>
    </message>
    <message>
        <source>Your current balance in watch-only addresses</source>
        <translation>Жорий балансингиз фақат кўринадиган манзилларда</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>Сарфланадиган:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Сўнгги пул ўтказмалари</translation>
    </message>
    <message>
        <source>Unconfirmed transactions to watch-only addresses</source>
        <translation>Тасдиқланмаган ўтказмалар-фақат манзилларини кўриш</translation>
    </message>
    <message>
        <source>Current total balance in watch-only addresses</source>
        <translation>Жорий умумий баланс фақат кўринадиган манзилларда</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Ёпиш</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ёки</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Тўлов сўрови хато</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI осилиб қолмоқда</translation>
    </message>
    <message>
        <source>Invalid payment address</source>
        <translation>Нотўғри тўлов манзили</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>Фойдаланувчи вакил</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тури</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Миқдори</translation>
    </message>
    <message>
        <source>Enter a Bitcoin address (e.g. %1)</source>
        <translation>Bitcoin манзилини киритинг (масалан.  %1)</translation>
    </message>
    <message>
        <source>Inbound</source>
        <translation>Ички йўналиш</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 д</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation>%1 с</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Йўқ</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Тўғри келмайди</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation>%1 мс</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation><numerusform>%n соат</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation><numerusform>%n кун</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n ҳафта</numerusform></translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 ва %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation><numerusform>%n йил</numerusform></translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 Б</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 КБ</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 МБ</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 ГБ</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>Номаълум</translation>
    </message>
    <message>
        <source>Blk</source>
        <comment>Tx Watch: Block type abbreviation</comment>
        <translation>блок</translation>
    </message>
    <message>
        <source>Txn</source>
        <comment>Tx Watch: Transaction type abbreviation</comment>
        <translation>Ўтказма</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>Расмни &amp;сақлаш</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Расмдан &amp;нусха олиш</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation>QR кодни сақлаш</translation>
    </message>
    <message>
        <source>PNG Image (*.png)</source>
        <translation>PNG расм (*.png)</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>Тўғри келмайди</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Мижоз номи</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Маълумот</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Асосий</translation>
    </message>
    <message>
        <source>Using BerkeleyDB version</source>
        <translation>Фойдаланилаётган BerkeleyDB версияси</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Бошланиш вақти</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Тармоқ</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ном</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Ҳамён: </translation>
    </message>
    <message>
        <source>&amp;Peers</source>
        <translation>&amp;Уламлар</translation>
    </message>
    <message>
        <source>Select a peer to view detailed information.</source>
        <translation>Батафсил маълумотларни кўриш учун уламни танланг.</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>Фойдаланувчи вакил</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Хизматлар</translation>
    </message>
    <message>
        <source>Connection Time</source>
        <translation>Уланиш вақти</translation>
    </message>
    <message>
        <source>Last Send</source>
        <translation>Сўнгги жўнатилган</translation>
    </message>
    <message>
        <source>Last Receive</source>
        <translation>Сўнгги қабул қилинган</translation>
    </message>
    <message>
        <source>Ping Time</source>
        <translation>Ping вақти</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Сўнгги блок вақти</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Очиш</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Терминал</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Тармоқ трафиги</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Ичига:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Ташқарига:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Тузатиш журнали файли</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Терминални тозалаш</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Га</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Дан</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Йўқ</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;Манзилни нусхалаш</translation>
    </message>
    <message>
        <source>via %1</source>
        <translation>%1 орқали</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Номаълум</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Миқдор:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Ёрлиқ:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Хабар:</translation>
    </message>
    <message>
        <source>An optional label to associate with the new receiving address.</source>
        <translation>Янги қабул қилинаётган манзил билан боғланган танланадиган ёрлиқ.</translation>
    </message>
    <message>
        <source>Use this form to request payments. All fields are &lt;b&gt;optional&lt;/b&gt;.</source>
        <translation>Ушбу сўровдан тўловларни сўраш учун фойдаланинг. Барча майдонлар &lt;b&gt;мажбурий эмас&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>An optional amount to request. Leave this empty or zero to not request a specific amount.</source>
        <translation>Хоҳланган миқдор сўрови. Кўрсатилган миқдорни сўраш учун буни бўш ёки ноль қолдиринг.</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>Тўловни &amp;сўраш</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Шаклнинг барча майдончаларини тозалаш</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Тозалаш</translation>
    </message>
    <message>
        <source>Requested payments history</source>
        <translation>Сўралган тўлов тарихи</translation>
    </message>
    <message>
        <source>Show the selected request (does the same as double clicking an entry)</source>
        <translation>Танланган сўровни кўрсатиш (икки марта босилганда ҳам бир хил амал бажарилсин)</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Кўрсатиш</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation>Танланганларни рўйхатдан ўчириш</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ўчириш</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Манзилни нусхалаш</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Ёрликни нусхала</translation>
    </message>
    <message>
        <source>Copy &amp;message</source>
        <translation type="unfinished">&amp;Хабарни нусхала</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Кийматни нусхала</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Ҳамён қулфдан чиқмади.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Request payment to ...</source>
        <translation type="unfinished">... дан Тўловни сўраш</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Манзил:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Миқдори:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Ёрлиқ:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Хабар</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Ҳамён:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Нусҳалаш &amp; Манзил</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>Расмни &amp;сақлаш</translation>
    </message>
    <message>
        <source>Request payment to %1</source>
        <translation> %1 дан Тўловни сўраш</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>Тўлов маълумоти</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Сана</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Ёрлиқ</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Хабар</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Ёрлиқ мавжуд эмас)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(Хабар йўқ)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Тангаларни жунат</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Танга бошқаруви ҳусусиятлари</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>автоматик тарзда танланган</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Кам миқдор</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Сони:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Байт:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Миқдори:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Солиқ:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Солиқдан сўнг:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Ўзгартириш:</translation>
    </message>
    <message>
        <source>If this is activated, but the change address is empty or invalid, change will be sent to a newly generated address.</source>
        <translation>Агар бу фаоллаштирилса, аммо ўзгартирилган манзил бўл ёки нотўғри бўлса, ўзгариш янги яратилган манзилга жўнатилади.</translation>
    </message>
    <message>
        <source>Custom change address</source>
        <translation>Бошқа ўзгартирилган манзил</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Ўтказма тўлови</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Танлов</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation>Хар килобайтига</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Тавсия этилган</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Бирданига бир нечта қабул қилувчиларга жўнатиш</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Шаклнинг барча майдончаларини тозалаш</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Ахлат қутиси:</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Барчасини &amp; Тозалаш</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Баланс</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Жўнатиш амалини тасдиқлаш</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>Жў&amp;натиш</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Нусха сони</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Кийматни нусхала</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Нусха солиғи</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Нусха солиқдан сўнг</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Нусха байти</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Нусха чангги</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Нусха қайтими</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 дан %2</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>Жўнатишни хоҳлашингизга ишончингиз комилми?</translation>
    </message>
    <message>
        <source>or</source>
        <translation>ёки</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Ўтказма тўлови</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Тангалар жўнаишни тасдиқлаш</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">Жўнатиш</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Тўлов миқдори 0. дан катта бўлиши керак. </translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation>Диққат: Нотўғр Bitcoin манзили</translation>
    </message>
    <message>
        <source>Warning: Unknown change address</source>
        <translation>Диққат: Номаълум ўзгариш манзили</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Ёрлиқ мавжуд эмас)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Миқдори:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>&amp;Тўлов олувчи:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Ёрлиқ:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Олдин фойдаланилган манзилни танла</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Клипбоарддан манзилни қўйиш</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Хабар</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Тўлов олувчи:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Choose previously used address</source>
        <translation>Олдин фойдаланилган манзилни танла</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Клипбоарддан манзилни қўйиш</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Имзо</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Барчасини &amp; Тозалаш</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>Хабарни &amp;тасдиқлаш</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">Хабарни &amp;тасдиқлаш</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Хабар тасдиқланди.</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>%1 гача очиш</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/тасдиқланмади</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 тасдиқлашлар</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Сана</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Манба</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>Яратилган</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Дан</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>Номаълум</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Га</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>ўз манзили</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>Фақат кўришга</translation>
    </message>
    <message>
        <source>label</source>
        <translation>ёрлиқ</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Кредит (қарз)</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>қабул қилинмади</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Ўтказма тўлови</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Умумий миқдор</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Хабар</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Шарҳ</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation>Савдо</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Ўтказма</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Миқдори</translation>
    </message>
    <message>
        <source>true</source>
        <translation>рост</translation>
    </message>
    <message>
        <source>false</source>
        <translation>ёлғон</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ушбу ойна операциянинг батафсил таърифини кўрсатади</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Сана</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тури</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Ёрлиқ</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>%1 гача очиш</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Тасдиқланмаган</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Тасдиқланди (%1 та тасдиқ)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Яратилди, аммо қабул қилинмади</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ёрдамида қабул қилиш</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Дан қабул қилиш</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Жўнатиш</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Ўзингизга тўлов</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Фойда</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>Фақат кўришга</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(қ/қ)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(Ёрлиқ мавжуд эмас)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Ўтказма ҳолати. Ушбу майдон бўйлаб тасдиқлашлар сонини кўрсатиш.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Ўтказма қабул қилинган сана ва вақт.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Пул ўтказмаси тури</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Миқдор ўчирилган ёки балансга қўшилган.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Барча</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Бугун</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Шу ҳафта</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Шу ой</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Ўтган хафта</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Шу йил</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Оралиқ...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ёрдамида қабул қилиш</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Жўнатиш</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Фойда</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Бошка</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Мин қиймат</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Манзилни нусхалаш</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">&amp;Ёрликни нусхала</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;Кийматни нусхала</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">&amp;Ўтказам рақамидан нусха олиш</translation>
    </message>
    <message>
        <source>&amp;Edit label</source>
        <translation type="unfinished">&amp;Ёрликни тахрирлаш</translation>
    </message>
    <message>
        <source>&amp;Show transaction details</source>
        <translation type="unfinished">&amp;Ўтказма тафсилотларини кўрсатиш </translation>
    </message>
    <message>
        <source>Export Transaction History</source>
        <translation>Ўтказмалар тарихини экспорт қилиш</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Вергул билан ажратилган файл (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Тасдиқланди</translation>
    </message>
    <message>
        <source>Watch-only</source>
        <translation>Фақат кўришга</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Сана</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тури</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Ёрлиқ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Манзил</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Экспорт қилиб бўлмади</translation>
    </message>
    <message>
        <source>The transaction history was successfully saved to %1.</source>
        <translation>Ўтказмалар тарихи %1 га муваффаққиятли сақланди.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Оралиқ:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>Кимга</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>Хатолик</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Тангаларни жунат</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Экспорт</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Жорий ички ойна ичидаги маълумотларни файлга экспорт қилиш</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">Ҳамённи заҳиралаш</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Бекор қилиш</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Хатолик</translation>
    </message>
    <message>
        <source>Loading P2P addresses...</source>
        <translation>Манзиллар юкланмоқда...</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Кам миқдор</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Тўсиқ индекси юкланмоқда...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Ҳамён юкланмоқда...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Қайта текшириб чиқилмоқда...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Юклаш тайёр</translation>
    </message>
</context>
</TS>